==> gat-0.8.3.tar.gz: gat-0.8.3/docs/languages.md <==
# Languages

| Language | Aliases |
| --- | --- |
| `ABAP` | `abap` |
| `ABNF` | `abnf` |
| `ActionScript` | `as`, `actionscript` |
| `ActionScript 3` | `as3`, `actionscript3` |
| `Ada` | `ada`, `ada95`, `ada2005` |
| `AL` | `al` |
| `Angular2` | `ng2` |
| `ANTLR` | `antlr` |
| `ApacheConf` | `apacheconf`, `aconf`, `apache` |
| `APL` | `apl` |
| `AppleScript` | `applescript` |
| `Arduino` | `arduino` |
| `ArmAsm` | `armasm` |
| `Awk` | `awk`, `gawk`, `mawk`, `nawk` |
| `Ballerina` | `ballerina` |
| `Bash` | `bash`, `sh`, `ksh`, `zsh`, `shell` |
| `BashSession` | `bash-session`, `console`, `shell-session` |
| `Batchfile` | `bat`, `batch`, `dosbatch`, `winbatch` |
| `BibTeX` | `bib`, `bibtex` |
| `Bicep` | `bicep` |
| `BlitzBasic` | `blitzbasic`, `b3d`, `bplus` |
| `BNF` | `bnf` |
| `BQN` | `bqn` |
| `Brainfuck` | `brainfuck`, `bf` |
| `C++` | `cpp`, `c++` |
| `C` | `c` |
| `Cap'n Proto` | `capnp` |
| `Ceylon` | `ceylon` |
| `CFEngine3` | `cfengine3`, `cf3` |
| `cfstatement` | `cfs` |
| `ChaiScript` | `chai`, `chaiscript` |
| `Clojure` | `clojure`, `clj` |
| `CMake` | `cmake` |
| `COBOL` | `cobol` |
| `CoffeeScript` | `coffee-script`, `coffeescript`, `coffee` |
| `Common Lisp` | `common-lisp`, `cl`, `lisp` |
| `Coq` | `coq` |
| `Crystal` | `cr`, `crystal` |
| `C#` | `csharp`, `c#` |
| `CSS` | `css` |
| `Cython` | `cython`, `pyx`, `pyrex` |
| `D` | `d` |
| `Dart` | `dart` |
| `Diff` | `diff`, `udiff` |
| `Django/Jinja` | `django`, `jinja` |
| `dns` | `zone`, `bind` |
| `DTD` | `dtd` |
| `Dylan` | `dylan` |
| `EBNF` | `ebnf` |
| `Elixir` | `elixir`, `ex`, `exs` |
| `Elm` | `elm` |
| `EmacsLisp` | `emacs`, `elisp`, `emacs-lisp` |
| `Erlang` | `erlang` |
| `Factor` | `factor` |
| `Fennel` | `fennel`, `fnl` |
| `Fish` | `fish`, `fishshell` |
| `Forth` | `forth` |
| `Fortran` | `fortran`, `f90` |
| `FSharp` | `fsharp` |
| `GAS` | `gas`, `asm` |
| `GDScript` | `gdscript`, `gd` |
| `Gherkin` | `cucumber`, `Cucumber`, `gherkin`, `Gherkin` |
| `GLSL` | `glsl` |
| `Gnuplot` | `gnuplot` |
| `Go HTML Template` | `go-html-template` |
| `GraphQL` | `graphql`, `graphqls`, `gql` |
| `Groff` | `groff`, `nroff`, `man` |
| `Groovy` | `groovy` |
| `Handlebars` | `handlebars`, `hbs` |
| `Haskell` | `haskell`, `hs` |
| `HCL` | `hcl` |
| `Hexdump` | `hexdump` |
| `HLB` | `hlb` |
| `HLSL` | `hlsl` |
| `HolyC` | `holyc` |
| `Hy` | `hylang` |
| `Idris` | `idris`, `idr` |
| `Igor` | `igor`, `igorpro` |
| `INI` | `ini`, `cfg`, `dosini` |
| `Io` | `io` |
| `J` | `j` |
| `Java` | `java` |
| `JavaScript` | `js`, `javascript` |
| `JSON` | `json` |
| `Julia` | `julia`, `jl` |
| `Jungle` | `jungle` |
| `Kotlin` | `kotlin` |
| `Lighttpd configuration file` | `lighty`, `lighttpd` |
| `LLVM` | `llvm` |
| `Lua` | `lua` |
| `Mathematica` | `mathematica`, `mma`, `nb` |
| `Matlab` | `matlab` |
| `mcfunction` | `mcfunction` |
| `Meson` | `meson`, `meson.build` |
| `Metal` | `metal` |
| `MiniZinc` | `minizinc`, `MZN`, `mzn` |
| `MLIR` | `mlir` |
| `Modula-2` | `modula2`, `m2` |
| `MonkeyC` | `monkeyc` |
| `MorrowindScript` | `morrowind`, `mwscript` |
| `MySQL` | `mysql`, `mariadb` |
| `NASM` | `nasm` |
| `Natural` | `natural` |
| `Newspeak` | `newspeak` |
| `Nginx configuration file` | `nginx` |
| `Nim` | `nim`, `nimrod` |
| `Nix` | `nixos`, `nix` |
| `Objective-C` | `objective-c`, `objectivec`, `obj-c`, `objc` |
| `OCaml` | `ocaml` |
| `Octave` | `octave` |
| `OnesEnterprise` | `ones`, `onesenterprise`, `1S`, `1S:Enterprise` |
| `OpenSCAD` | `openscad` |
| `PacmanConf` | `pacmanconf` |
| `Perl` | `perl`, `pl` |
| `PHP` | `php`, `php3`, `php4`, `php5` |
| `Pig` | `pig` |
| `PkgConfig` | `pkgconfig` |
| `PL/pgSQL` | `plpgsql` |
| `Plutus Core` | `plutus-core`, `plc` |
| `Pony` | `pony` |
| `PostScript` | `postscript`, `postscr` |
| `POVRay` | `pov` |
| `PowerQuery` | `powerquery`, `pq` |
| `PowerShell` | `powershell`, `posh`, `ps1`, `psm1`, `psd1`, `pwsh` |
| `Prolog` | `prolog` |
| `PromQL` | `promql` |
| `properties` | `java-properties` |
| `Protocol Buffer` | `protobuf`, `proto` |
| `PSL` | `psl` |
| `Puppet` | `puppet` |
| `Python` | `python`, `py`, `sage`, `python3`, `py3` |
| `Python 2` | `python2`, `py2` |
| `QBasic` | `qbasic`, `basic` |
| `QML` | `qml`, `qbs` |
| `R` | `splus`, `s`, `r` |
| `Racket` | `racket`, `rkt` |
| `Ragel` | `ragel` |
| `react` | `jsx`, `react` |
| `ReasonML` | `reason`, `reasonml` |
| `reg` | `registry` |
| `Rexx` | `rexx`, `arexx` |
| `Ruby` | `rb`, `ruby`, `duby` |
| `Rust` | `rust`, `rs` |
| `SAS` | `sas` |
| `Sass` | `sass` |
| `Scala` | `scala` |
| `Scheme` | `scheme`, `scm` |
| `Scilab` | `scilab` |
| `SCSS` | `scss` |
| `Sed` | `sed`, `gsed`, `ssed` |
| `Sieve` | `sieve` |
| `Smalltalk` | `smalltalk`, `squeak`, `st` |
| `Snobol` | `snobol` |
| `Solidity` | `sol`, `solidity` |
| `SPARQL` | `sparql` |
| `SQL` | `sql` |
| `SquidConf` | `squidconf`, `squid.conf`, `squid` |
| `Standard ML` | `sml` |
| `stas` | |
| `Stylus` | `stylus` |
| `Swift` | `swift` |
| `SYSTEMD` | `systemd` |
| `systemverilog` | `systemverilog`, `sv` |
| `TableGen` | `tablegen` |
| `TASM` | `tasm` |
| `Tcl` | `tcl` |
| `Tcsh` | `tcsh`, `csh` |
| `Termcap` | `termcap` |
| `Terminfo` | `terminfo` |
| `Terraform` | `terraform`, `tf` |
| `TeX` | `tex`, `latex` |
| `Thrift` | `thrift` |
| `TOML` | `toml` |
| `TradingView` | `tradingview`, `tv` |
| `Transact-SQL` | `tsql`, `t-sql` |
| `Turing` | `turing` |
| `Turtle` | `turtle` |
| `Twig` | `twig` |
| `TypeScript` | `ts`, `tsx`, `typescript` |
| `TypoScriptCssData` | `typoscriptcssdata` |
| `TypoScriptHtmlData` | `typoscripthtmldata` |
| `Vala` | `vala`, `vapi` |
| `VB.net` | `vb.net`, `vbnet` |
| `verilog` | `verilog`, `v` |
| `VHDL` | `vhdl` |
| `VHS` | `vhs`, `tape`, `cassette` |
| `vue` | `vue`, `vuejs` |
| `WDTE` | |
| `Whiley` | `whiley` |
| `XML` | `xml` |
| `Xorg` | `xorg.conf` |
| `YAML` | `yaml` |
| `YANG` | `yang` |
| `Z80 Assembly` | `z80` |
| `Zed` | `zed` |
| `Zig` | `zig` |
| `Caddyfile` | `caddyfile`, `caddy` |
| `Caddyfile Directives` | `caddyfile-directives`, `caddyfile-d`, `caddy-d` |
| `Chapel` | `chapel`, `chpl` |
| `Cheetah` | `cheetah`, `spitfire` |
| `Common Lisp` | `common-lisp`, `cl`, `lisp` |
| `Cassandra CQL` | `cassandra`, `cql` |
| `Docker` | `docker`, `dockerfile` |
| `EmacsLisp` | `emacs`, `elisp`, `emacs-lisp` |
| `FortranFixed` | `fortranfixed` |
| `Genshi Text` | `genshitext` |
| `Genshi HTML` | `html+genshi`, `html+kid` |
| `Genshi` | `genshi`, `kid`, `xml+genshi`, `xml+kid` |
| `Go Text Template` | `go-text-template` |
| `Go` | `go`, `golang` |
| `HTML` | `html` |
| `Go HTML Template` | `go-html-template` |
| `Haxe` | `hx`, `haxe`, `hxsl` |
| `HTTP` | `http` |
| `Makefile` | `make`, `makefile`, `mf`, `bsdmake` |
| `Mako` | `mako` |
| `markdown` | `md`, `mkd` |
| `Mason` | `mason` |
| `Myghty` | `myghty` |
| `OpenEdge ABL` | `openedge`, `abl`, `progress`, `openedgeabl` |
| `Org Mode` | `org`, `orgmode` |
| `PHTML` | `phtml` |
| `plaintext` | `text`, `plain`, `no-highlight` |
| `PostgreSQL SQL dialect` | `postgresql`, `postgres` |
| `Raku` | `perl6`, `pl6`, `raku` |
| `reStructuredText` | `rst`, `rest`, `restructuredtext` |
| `Smarty` | `smarty` |
| `Svelte` | `svelte` |
| `TypoScript` | `typoscript` |
| `V` | `v`, `vlang` |
| `V shell` | `vsh`, `vshell` |
| `VimL` | `vim` |

==> gat-0.10.0.tar.gz: gat-0.10.0/docs/languages.md <==
# Languages

| Language | Aliases |
| --- | --- |
| `ABAP` | `abap` |
| `ABNF` | `abnf` |
| `ActionScript` | `as`, `actionscript` |
| `ActionScript 3` | `as3`, `actionscript3` |
| `Ada` | `ada`, `ada95`, `ada2005` |
| `AL` | `al` |
| `Angular2` | `ng2` |
| `ANTLR` | `antlr` |
| `ApacheConf` | `apacheconf`, `aconf`, `apache` |
| `APL` | `apl` |
| `AppleScript` | `applescript` |
| `ArangoDB AQL` | `aql` |
| `Arduino` | `arduino` |
| `ArmAsm` | `armasm` |
| `AutoHotkey` | `autohotkey`, `ahk` |
| `AutoIt` | `autoit` |
| `Awk` | `awk`, `gawk`, `mawk`, `nawk` |
| `Ballerina` | `ballerina` |
| `Bash` | `bash`, `sh`, `ksh`, `zsh`, `shell` |
| `BashSession` | `bash-session`, `console`, `shell-session` |
| `Batchfile` | `bat`, `batch`, `dosbatch`, `winbatch` |
| `BibTeX` | `bib`, `bibtex` |
| `Bicep` | `bicep` |
| `BlitzBasic` | `blitzbasic`, `b3d`, `bplus` |
| `BNF` | `bnf` |
| `BQN` | `bqn` |
| `Brainfuck` | `brainfuck`, `bf` |
| `C++` | `cpp`, `c++` |
| `C` | `c` |
| `Cap'n Proto` | `capnp` |
| `Ceylon` | `ceylon` |
| `CFEngine3` | `cfengine3`, `cf3` |
| `cfstatement` | `cfs` |
| `ChaiScript` | `chai`, `chaiscript` |
| `Clojure` | `clojure`, `clj` |
| `CMake` | `cmake` |
| `COBOL` | `cobol` |
| `CoffeeScript` | `coffee-script`, `coffeescript`, `coffee` |
| `Common Lisp` | `common-lisp`, `cl`, `lisp` |
| `Coq` | `coq` |
| `Crystal` | `cr`, `crystal` |
| `C#` | `csharp`, `c#` |
| `CSS` | `css` |
| `Cython` | `cython`, `pyx`, `pyrex` |
| `D` | `d` |
| `Dart` | `dart` |
| `Diff` | `diff`, `udiff` |
| `Django/Jinja` | `django`, `jinja` |
| `dns` | `zone`, `bind` |
| `DTD` | `dtd` |
| `Dylan` | `dylan` |
| `EBNF` | `ebnf` |
| `Elixir` | `elixir`, `ex`, `exs` |
| `Elm` | `elm` |
| `EmacsLisp` | `emacs`, `elisp`, `emacs-lisp` |
| `Erlang` | `erlang` |
| `Factor` | `factor` |
| `Fennel` | `fennel`, `fnl` |
| `Fish` | `fish`, `fishshell` |
| `Forth` | `forth` |
| `Fortran` | `fortran`, `f90` |
| `FSharp` | `fsharp` |
| `GAS` | `gas`, `asm` |
| `GDScript` | `gdscript`, `gd` |
| `Gherkin` | `cucumber`, `Cucumber`, `gherkin`, `Gherkin` |
| `GLSL` | `glsl` |
| `Gnuplot` | `gnuplot` |
| `Go HTML Template` | `go-html-template` |
| `GraphQL` | `graphql`, `graphqls`, `gql` |
| `Groff` | `groff`, `nroff`, `man` |
| `Groovy` | `groovy` |
| `Handlebars` | `handlebars`, `hbs` |
| `Haskell` | `haskell`, `hs` |
| `HCL` | `hcl` |
| `Hexdump` | `hexdump` |
| `HLB` | `hlb` |
| `HLSL` | `hlsl` |
| `HolyC` | `holyc` |
| `Hy` | `hylang` |
| `Idris` | `idris`, `idr` |
| `Igor` | `igor`, `igorpro` |
| `INI` | `ini`, `cfg`, `dosini` |
| `Io` | `io` |
| `ISCdhcpd` | `iscdhcpd` |
| `J` | `j` |
| `Java` | `java` |
| `JavaScript` | `js`, `javascript` |
| `JSON` | `json` |
| `Julia` | `julia`, `jl` |
| `Jungle` | `jungle` |
| `Kotlin` | `kotlin` |
| `Lighttpd configuration file` | `lighty`, `lighttpd` |
| `LLVM` | `llvm` |
| `Lua` | `lua` |
| `Mathematica` | `mathematica`, `mma`, `nb` |
| `Matlab` | `matlab` |
| `mcfunction` | `mcfunction` |
| `Meson` | `meson`, `meson.build` |
| `Metal` | `metal` |
| `MiniZinc` | `minizinc`, `MZN`, `mzn` |
| `MLIR` | `mlir` |
| `Modula-2` | `modula2`, `m2` |
| `MonkeyC` | `monkeyc` |
| `MorrowindScript` | `morrowind`, `mwscript` |
| `MySQL` | `mysql`, `mariadb` |
| `NASM` | `nasm` |
| `Natural` | `natural` |
| `Newspeak` | `newspeak` |
| `Nginx configuration file` | `nginx` |
| `Nim` | `nim`, `nimrod` |
| `Nix` | `nixos`, `nix` |
| `Objective-C` | `objective-c`, `objectivec`, `obj-c`, `objc` |
| `OCaml` | `ocaml` |
| `Octave` | `octave` |
| `OnesEnterprise` | `ones`, `onesenterprise`, `1S`, `1S:Enterprise` |
| `OpenSCAD` | `openscad` |
| `PacmanConf` | `pacmanconf` |
| `Perl` | `perl`, `pl` |
| `PHP` | `php`, `php3`, `php4`, `php5` |
| `Pig` | `pig` |
| `PkgConfig` | `pkgconfig` |
| `PL/pgSQL` | `plpgsql` |
| `Plutus Core` | `plutus-core`, `plc` |
| `Pony` | `pony` |
| `PostScript` | `postscript`, `postscr` |
| `POVRay` | `pov` |
| `PowerQuery` | `powerquery`, `pq` |
| `PowerShell` | `powershell`, `posh`, `ps1`, `psm1`, `psd1`, `pwsh` |
| `Prolog` | `prolog` |
| `PromQL` | `promql` |
| `properties` | `java-properties` |
| `Protocol Buffer` | `protobuf`, `proto` |
| `PSL` | `psl` |
| `Puppet` | `puppet` |
| `Python` | `python`, `py`, `sage`, `python3`, `py3` |
| `Python 2` | `python2`, `py2` |
| `QBasic` | `qbasic`, `basic` |
| `QML` | `qml`, `qbs` |
| `R` | `splus`, `s`, `r` |
| `Racket` | `racket`, `rkt` |
| `Ragel` | `ragel` |
| `react` | `jsx`, `react` |
| `ReasonML` | `reason`, `reasonml` |
| `reg` | `registry` |
| `Rexx` | `rexx`, `arexx` |
| `Ruby` | `rb`, `ruby`, `duby` |
| `Rust` | `rust`, `rs` |
| `SAS` | `sas` |
| `Sass` | `sass` |
| `Scala` | `scala` |
| `Scheme` | `scheme`, `scm` |
| `Scilab` | `scilab` |
| `SCSS` | `scss` |
| `Sed` | `sed`, `gsed`, `ssed` |
| `Sieve` | `sieve` |
| `Smali` | `smali` |
| `Smalltalk` | `smalltalk`, `squeak`, `st` |
| `Snobol` | `snobol` |
| `Solidity` | `sol`, `solidity` |
| `SPARQL` | `sparql` |
| `SQL` | `sql` |
| `SquidConf` | `squidconf`, `squid.conf`, `squid` |
| `Standard ML` | `sml` |
| `stas` | |
| `Stylus` | `stylus` |
| `Swift` | `swift` |
| `SYSTEMD` | `systemd` |
| `systemverilog` | `systemverilog`, `sv` |
| `TableGen` | `tablegen` |
| `Tal` | `tal`, `uxntal` |
| `TASM` | `tasm` |
| `Tcl` | `tcl` |
| `Tcsh` | `tcsh`, `csh` |
| `Termcap` | `termcap` |
| `Terminfo` | `terminfo` |
| `Terraform` | `terraform`, `tf` |
| `TeX` | `tex`, `latex` |
| `Thrift` | `thrift` |
| `TOML` | `toml` |
| `TradingView` | `tradingview`, `tv` |
| `Transact-SQL` | `tsql`, `t-sql` |
| `Turing` | `turing` |
| `Turtle` | `turtle` |
| `Twig` | `twig` |
| `TypeScript` | `ts`, `tsx`, `typescript` |
| `TypoScriptCssData` | `typoscriptcssdata` |
| `TypoScriptHtmlData` | `typoscripthtmldata` |
| `Vala` | `vala`, `vapi` |
| `VB.net` | `vb.net`, `vbnet` |
| `verilog` | `verilog`, `v` |
| `VHDL` | `vhdl` |
| `VHS` | `vhs`, `tape`, `cassette` |
| `vue` | `vue`, `vuejs` |
| `WDTE` | |
| `WebGPU Shading Language` | `wgsl` |
| `Whiley` | `whiley` |
| `XML` | `xml` |
| `Xorg` | `xorg.conf` |
| `YAML` | `yaml` |
| `YANG` | `yang` |
| `Z80 Assembly` | `z80` |
| `Zed` | `zed` |
| `Zig` | `zig` |
| `Caddyfile` | `caddyfile`, `caddy` |
| `Caddyfile Directives` | `caddyfile-directives`, `caddyfile-d`, `caddy-d` |
| `Chapel` | `chapel`, `chpl` |
| `Cheetah` | `cheetah`, `spitfire` |
| `Common Lisp` | `common-lisp`, `cl`, `lisp` |
| `Cassandra CQL` | `cassandra`, `cql` |
| `Docker` | `docker`, `dockerfile` |
| `EmacsLisp` | `emacs`, `elisp`, `emacs-lisp` |
| `FortranFixed` | `fortranfixed` |
| `Genshi Text` | `genshitext` |
| `Genshi HTML` | `html+genshi`, `html+kid` |
| `Genshi` | `genshi`, `kid`, `xml+genshi`, `xml+kid` |
| `Go Text Template` | `go-text-template` |
| `Go` | `go`, `golang` |
| `HTML` | `html` |
| `Go HTML Template` | `go-html-template` |
| `Haxe` | `hx`, `haxe`, `hxsl` |
| `HTTP` | `http` |
| `Makefile` | `make`, `makefile`, `mf`, `bsdmake` |
| `Mako` | `mako` |
| `markdown` | `md`, `mkd` |
| `Mason` | `mason` |
| `Myghty` | `myghty` |
| `OpenEdge ABL` | `openedge`, `abl`, `progress`, `openedgeabl` |
| `Org Mode` | `org`, `orgmode` |
| `PHTML` | `phtml` |
| `plaintext` | `text`, `plain`, `no-highlight` |
| `PostgreSQL SQL dialect` | `postgresql`, `postgres` |
| `Raku` | `perl6`, `pl6`, `raku` |
| `reStructuredText` | `rst`, `rest`, `restructuredtext` |
| `Smarty` | `smarty` |
| `Svelte` | `svelte` |
| `TypoScript` | `typoscript` |
| `V` | `v`, `vlang` |
| `V shell` | `vsh`, `vshell` |
| `VimL` | `vim` |
